Crate kcr_troubleshoot_sh

Crate kcr_troubleshoot_sh 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the troubleshoot.sh group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

troubleshoot.sh/v1beta2

  • Analyzer
  • Collector
  • HostCollector
  • HostPreflight
  • Preflight
  • Redactor
  • RemoteCollector
  • SupportBundle

Modules

v1beta2