This crate contains kube-rs compatible bindings for Kubernetes custom resources for the troubleshoot.sh group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
troubleshoot.sh/v1beta2
AnalyzerCollectorHostCollectorHostPreflightPreflightRedactorRemoteCollectorSupportBundle